@@ -11,8 +11,10 @@
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
 
+
 import os, sys, shlex, tempfile, shutil, re
 import subprocess, hashlib
+from timeit import default_timer
 from collections.abc import Iterable
 from contextlib import contextmanager
 from multiprocessing import Process, Event
@@ -253,5 +255,12 @@ class RepeatableTimer:
                 break
             self.finished.wait(self.interval)     
 
+class Benchmark:
+    def __enter__(self):
+        self.start = default_timer()
+        return self
+
+    def __exit__(self, *args):
+        self.time = default_timer() - self.start
 
 
